import sys
from scribe.git_utils import parse_git_diff
from scribe.pull_request_utils import get_pull_request_info, get_pull_request_diff
from scribe.config import get_model_config
from scribe.plugins import get_plugin


def generate_pr_description(pr_number):
    try:
        base_branch, head_branch, commit_messages = get_pull_request_info(pr_number)
        diff = get_pull_request_diff(base_branch, head_branch)

        # Use the new parse_git_diff function
        diff_summary = parse_git_diff(diff)

        # Get the model configuration
        config = get_model_config()
        # Get the appropriate plugin
        plugin = get_plugin(config)

        # Generate pull request description
        pr_description = plugin.generate_pull_request_message(diff_summary, commit_messages)

        print(f"# Generated by ZScribe using {config['provider']} {config['model']}\n")
        print("# Please review and edit the pull request description as needed.")
        print(pr_description)

    except Exception as e:
        print(f"Error generating pull request description: {e}")
        print("Please write your pull request description manually.")


if __name__ == "__main__":
    generate_pr_description(sys.argv[1])
